<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="hu">
<context>
    <name>OptionsWidget</name>
    <message>
        <location filename="../../OptionsWidget.ui" line="17"/>
        <source>In normal case, only the dll 64Bits is important with 64Bits OS, and 32Bits dll with 32Bits OS. When it&apos;s important, the UAC can be opened to load the dll.</source>
        <translation>Normális esetben csak a 64 bites dll fontos a 64 bites és a 32 bites dll a 32 bites operációs rendszer számára.Amikor lényeges, az UAC megnyitható a dll betöltéséhez.</translation>
    </message>
    <message>
        <location filename="../../OptionsWidget.ui" line="20"/>
        <source>All the dlls are importants</source>
        <translation>Az összes dll fontos</translation>
    </message>
    <message>
        <location filename="../../OptionsWidget.ui" line="34"/>
        <source>Register for all users</source>
        <translation type="unfinished"></translation>
    </message>
</context>
</TS>
